/**
 * \file
 *
 * \brief Empty user application template
 *
 */

/**
 * \mainpage User Application template doxygen documentation
 *
 * \par Empty user application template
 *
 * This is a bare minimum user application template.
 *
 * For documentation of the board, go \ref group_common_boards "here" for a link
 * to the board-specific documentation.
 *
 * \par Content
 *
 * -# Include the ASF header files (through asf.h)
 * -# Minimal main function that starts with a call to board_init()
 * -# Basic usage of on-board LED and button
 * -# "Insert application code here" comment
 *
 */

/*
 * Include header files for all drivers that have been imported from
 * Atmel Software Framework (ASF).
 */
/*
 * Support and FAQ: visit <a href="http://www.atmel.com/design-support/">Atmel Support</a>
 */
#include <asf.h>

//Port I/O
#define TC0_TIOA_CH1 IOPORT_CREATE_PIN(PIOA, 15)

//Timer configuration
#define TC0_CHANNEL1 1

int main (void)
{
	//clock configuration and initialization
	sysclk_init();
	
	/*Disable the watchdog timer and configure/initialize
	port pins connected to various components incorporated 
	into the SAM4S Xplained development platform, e.g., the 
	NAND flash, the OLED interface, the LEDs, the SW0 pushbutton.*/
	board_init();
	
	//enable peripheral clock for TC module 0 channel 1
	pmc_enable_periph_clk(ID_TC1);
	
	//connect peripheral B to pin A15
	pio_configure_pin(TC0_TIOA_CH1, PIO_TYPE_PIO_PERIPH_B);
	
	tc_init(TC0, TC0_CHANNEL1, 
							TC_CMR_TCCLKS_TIMER_CLOCK2	//MCK/8
						|	TC_CMR_WAVE	//waveform mode
						|	TC_CMR_WAVSEL_UP_RC	//count up, reset on RC match
						|	TC_CMR_ACPC_TOGGLE	//toggle TIOA on RC match
						);
	
	//load RC with 6 to obtain a 1 MHz square wave on TIOA
	tc_write_rc(TC0, TC0_CHANNEL1, 6);
	
	tc_start(TC0, TC0_CHANNEL1);
	
	while(1);
}
